@@ -60,3 +60,19 @@ class MorangoResumeSyncError(MorangoError):
 
 class MorangoContextUpdateError(MorangoError):
     pass
+
+
+class MorangoLimitExceeded(MorangoError):
+    pass
+
+
+class InvalidMorangoSourceId(MorangoError):
+    pass
+
+
+class MorangoInvalidFSICPartition(MorangoError):
+    pass
+
+
+class MorangoSkipOperation(MorangoError):
+    pass
